﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using System.Windows.Messaging;
using System.Collections.Generic;

namespace SilverlightClassLibrary1
{
    // Summary:
    //     Represents the receiving end of a local connection channel between two Silverlight-based
    //     applications.
    public sealed class LocalMessageReceiver : IDisposable
    {
        // Summary:
        //     A value that represents any domain.
        public static readonly IEnumerable<string> AnyDomain;

        // Summary:
        //     Initializes a new instance of the System.Windows.Messaging.LocalMessageReceiver
        //     class and configures it with the specified name.
        //
        // Parameters:
        //   receiverName:
        //     The name of the receiver.
        public LocalMessageReceiver(string receiverName);
        //
        // Summary:
        //     Initializes a new instance of the System.Windows.Messaging.LocalMessageReceiver
        //     class and configures it with the specified name, namescope requirement, and
        //     allowed sender domains.
        //
        // Parameters:
        //   receiverName:
        //     The name of the receiver, which must be unique either within the global namescope
        //     or the receiver's domain, depending on the value of the nameScope parameter.
        //
        //   nameScope:
        //     A value that indicates whether the receiverName is scoped to the global namescope
        //     or to the receiver's specific domain.
        //
        //   allowedSenderDomains:
        //     The domains that the receiver can receive messages from, or System.Windows.Messaging.LocalMessageReceiver.AnyDomain
        //     to receive from any domain.
        public LocalMessageReceiver(string receiverName, ReceiverNameScope nameScope, IEnumerable<string> allowedSenderDomains);

        // Summary:
        //     Gets the domains that the receiver can receive messages from.
        //
        // Returns:
        //     The domains that the receiver can receive messages from, or System.Windows.Messaging.LocalMessageReceiver.AnyDomain
        //     if the receiver can receive messages from any domain.
        public IEnumerable<string> AllowedSenderDomains { get; }
        //
        // Summary:
        //     Gets a value that indicates whether the System.Windows.Messaging.LocalMessageReceiver.ReceiverName
        //     is scoped to the global namescope or to the receiver's specific domain.
        //
        // Returns:
        //     A value that indicates whether the System.Windows.Messaging.LocalMessageReceiver.ReceiverName
        //     is scoped to the global namescope or to the receiver's specific domain.
        public ReceiverNameScope NameScope { get; }
        //
        // Summary:
        //     Gets the name of the receiver.
        //
        // Returns:
        //     The name of the receiver.
        public string ReceiverName { get; }

        // Summary:
        //     Occurs when a message is received from a System.Windows.Messaging.LocalMessageSender.
        public event EventHandler<MessageReceivedEventArgs> MessageReceived;

        // Summary:
        //     Stops the receiver from receiving messages and releases all resources used
        //     by the receiver.
        [SecuritySafeCritical]
        public void Dispose();
        //
        // Summary:
        //     Starts listening for messages from a System.Windows.Messaging.LocalMessageSender.
        [SecuritySafeCritical]
        public void Listen();
    }
}
