﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Windows.Media.Effects;

namespace _3_Perspective3D_Demo2
{
    public partial class MainPage : UserControl
    {
        #region [ Properties ]
        private Storyboard activeSpinStoryBoard = new Storyboard();
        private Image activeImage = new Image();
        private double activeImageOriginalLeft = 0.00;
        private double activeImageOriginalTop = 0.00;
        #endregion

        public MainPage()
        {
            InitializeComponent();

            //RunningOOBStatusTextBlock.Text = Application.Current.RunningOffline.ToString();
            //ExecutionStates currentExecutationState = Application.Current.ExecutionState;
            
            //NetworkAvailableStatusTextBlock.Text = System.Net.NetworkInformation.NetworkInterface.GetIsNetworkAvailable().ToString();

            LoadImages();
            activeImage.Projection = new PlaneProjection();
        }
        

        #region [ LoadImages ]
        private void LoadImages()
        {
            List<Image> pictures = new List<Image>();

            double currentWidth = 30.00;

            createImage("http://localhost:55812/Assets/Sonic.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/Zelda.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/SMG.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/FF.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/Fit.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/Goo.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/Punch.jpg", ref currentWidth);
            createImage("http://localhost:55812/Assets/Bengals.jpg", ref currentWidth);
        }
        #endregion

        #region [ createImage ]
        private void createImage(string url, ref double currentWidth)
        {
            Image img = new Image();
            img.Width = 100;

            img.Source = new BitmapImage(new Uri(url, UriKind.RelativeOrAbsolute));
            img.MouseLeftButtonDown += new MouseButtonEventHandler(img_MouseLeftButtonDown);
            img.MouseEnter += new MouseEventHandler(img_MouseHover);
            img.MouseLeave += new MouseEventHandler(img_MouseHover);
            SetInitialImageView(img);

            img.SetValue(Canvas.LeftProperty, currentWidth);
            img.SetValue(Canvas.TopProperty, 30.00);
            currentWidth += img.Width + 8.00;
            LayoutRoot.Children.Add(img);
        }
        #endregion

        #region [ img_MouseHover ]
        void img_MouseHover(object sender, MouseEventArgs e)
        {
            Image img = sender as Image;

            if (img != activeImage)
            {
                if (img.Effect == null)
                {
                    SetInitialImageView(img);
                }
                else
                {
                    img.Effect = null;
                }
            }
        }
        #endregion

        #region [ img_MouseLeftButtonDown ]
        void img_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            Image img = sender as Image;

            if (img != activeImage)
            {
                SetInitialImageView(activeImage);

                img.Effect = null;
                img.Projection = new PlaneProjection();

                Storyboard sb = new Storyboard { Duration = new Duration(TimeSpan.FromSeconds(0.7)) };

                if (RotateYCheckBox.IsChecked.Value)
                {
                    attachDoubleAnimation((DependencyObject)img.Projection, sb, sb.Duration, PlaneProjection.RotationYProperty, 0, 360);
                }

                if (RotateZCheckBox.IsChecked.Value)
                {
                    attachDoubleAnimation((DependencyObject)img.Projection, sb, sb.Duration, PlaneProjection.RotationZProperty, 0, 360);
                }

                if (RotateXCheckBox.IsChecked.Value)
                {
                    attachDoubleAnimation((DependencyObject)img.Projection, sb, sb.Duration, PlaneProjection.RotationXProperty, 0, 360);
                }

                attachDoubleAnimation((DependencyObject)img, sb, sb.Duration, Canvas.TopProperty, Convert.ToDouble(img.GetValue(Canvas.TopProperty)), 160);
                attachDoubleAnimation((DependencyObject)img, sb, sb.Duration, Canvas.LeftProperty, Convert.ToDouble(img.GetValue(Canvas.LeftProperty)), 50);
                attachDoubleAnimation((DependencyObject)img, sb, sb.Duration, Image.WidthProperty, Convert.ToDouble(img.Width), 600);

                try
                {
                    Storyboard sbActiveImage = new Storyboard { Duration = new Duration(TimeSpan.FromSeconds(0.30)) };

                    double currentTopProperty = Convert.ToDouble(activeImage.GetValue(Canvas.TopProperty));
                    double currentLeftProperty = Convert.ToDouble(activeImage.GetValue(Canvas.LeftProperty));

                    attachDoubleAnimation((DependencyObject)activeImage, sbActiveImage, sbActiveImage.Duration, Canvas.TopProperty, currentTopProperty, activeImageOriginalTop);
                    attachDoubleAnimation((DependencyObject)activeImage, sbActiveImage, sbActiveImage.Duration, Canvas.LeftProperty, currentLeftProperty, activeImageOriginalLeft);
                    attachDoubleAnimation((DependencyObject)activeImage, sbActiveImage, sbActiveImage.Duration, Image.WidthProperty, Convert.ToDouble(activeImage.Width), 100);

                    sbActiveImage.Begin();
                }
                catch { }

                sb.Begin();

                activeSpinStoryBoard = sb;
                activeImage = img;

                activeImageOriginalLeft = Convert.ToDouble(img.GetValue(Canvas.LeftProperty));
                activeImageOriginalTop = Convert.ToDouble(img.GetValue(Canvas.TopProperty));
                    
                if (ApplyDropShadowCheckBox.IsChecked.Value)
                {
                    DropShadowEffect drop = new DropShadowEffect();
                    drop.BlurRadius = 30;
                    drop.Opacity = 70;
                    drop.ShadowDepth = 30;

                    img.Effect = drop;
                }
            }
        }
        #endregion

        #region [ SetInitialImageView ]
        private static void SetInitialImageView(Image img)
        {
            BlurEffect blur = new BlurEffect();
            blur.Radius = 5;

            img.Effect = blur;
        }
        #endregion

        #region [ attachDoubleAnimation ]
        private void attachDoubleAnimation(DependencyObject element, Storyboard sb, Duration d, DependencyProperty prop, double fromValue, double toValue)
        {
            DoubleAnimation animation = new DoubleAnimation { Duration = d, To = toValue, From = fromValue };
            sb.Children.Add(animation);

            Storyboard.SetTarget(animation, element);
            Storyboard.SetTargetProperty(animation, new PropertyPath(prop));
        }
        #endregion
    }
}


